==> apache-ambari-2.6.2-src.tar.gz: apache-ambari-2.6.2-src/ambari-server/src/main/java/org/apache/ambari/server/utils/JaxbMapKeyMapAdapter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.utils;

import java.util.Map;
import java.util.TreeMap;

import javax.xml.bind.annotation.adapters.XmlAdapter;

public class JaxbMapKeyMapAdapter extends
    XmlAdapter<JaxbMapKeyMap[], Map<String, Map<String, String>>> {

  private static JaxbMapKeyValAdapter mapAdapter = new JaxbMapKeyValAdapter();

  @Override
  public JaxbMapKeyMap[] marshal(Map<String, Map<String, String>> map)
      throws Exception {
    if (map == null) {
      return null;
    }
    JaxbMapKeyMap[] list = new JaxbMapKeyMap[map.size()];
    int index=0;
    for (Map.Entry<String, Map<String, String>> stringMapEntry : map.entrySet()) {
      Map<String, String> value = stringMapEntry.getValue();
      JaxbMapKeyVal[] keyValList = mapAdapter.marshal(value);
      list[index++] = new JaxbMapKeyMap(stringMapEntry.getKey(), keyValList);
    }
    return list;
  }

  @Override
  public Map<String, Map<String, String>> unmarshal(JaxbMapKeyMap[] list)
      throws Exception {
    if (list == null) {
      return null;
    }
    Map<String, Map<String, String>> map = new TreeMap<String, Map<String, String>>();
    for (JaxbMapKeyMap jaxbkeyMap : list) {
      map.put(jaxbkeyMap.key, mapAdapter.unmarshal(jaxbkeyMap.value));
    }
    return map;
  }
}

==> apache-ambari-2.7.9-src.tar.gz: apache-ambari-2.7.9-src/ambari-server/src/main/java/org/apache/ambari/server/utils/JaxbMapKeyMapAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.utils;

import java.util.Map;
import java.util.TreeMap;

import javax.xml.bind.annotation.adapters.XmlAdapter;

public class JaxbMapKeyMapAdapter extends
    XmlAdapter<JaxbMapKeyMap[], Map<String, Map<String, String>>> {

  private static JaxbMapKeyValAdapter mapAdapter = new JaxbMapKeyValAdapter();

  @Override
  public JaxbMapKeyMap[] marshal(Map<String, Map<String, String>> map)
      throws Exception {
    if (map == null) {
      return null;
    }
    JaxbMapKeyMap[] list = new JaxbMapKeyMap[map.size()];
    int index=0;
    for (Map.Entry<String, Map<String, String>> stringMapEntry : map.entrySet()) {
      Map<String, String> value = stringMapEntry.getValue();
      JaxbMapKeyVal[] keyValList = mapAdapter.marshal(value);
      list[index++] = new JaxbMapKeyMap(stringMapEntry.getKey(), keyValList);
    }
    return list;
  }

  @Override
  public Map<String, Map<String, String>> unmarshal(JaxbMapKeyMap[] list)
      throws Exception {
    if (list == null) {
      return null;
    }
    Map<String, Map<String, String>> map = new TreeMap<>();
    for (JaxbMapKeyMap jaxbkeyMap : list) {
      map.put(jaxbkeyMap.key, mapAdapter.unmarshal(jaxbkeyMap.value));
    }
    return map;
  }
}
